#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import sys
import time
import threading

"""How to use the Spinner class
    spinner = Spinner("Loading")
    spinner.start()

    # Simulate a long-running process
    time.sleep(5)

    spinner.stop()
"""

class Spinner:
    def __init__(self, message="Processing"):
        self.message = message
        self.running = False
        self.thread = None

    def start(self):
        self.running = True
        self.thread = threading.Thread(target=self._animate)
        self.thread.start()

    def _animate(self):
        spinner_chars = "|/-\\"
        idx = 0
        while self.running:
            sys.stdout.write(f"\r{self.message}... {spinner_chars[idx]}")
            sys.stdout.flush()
            idx = (idx + 1) % len(spinner_chars)
            time.sleep(0.1)

    def stop(self):
        self.running = False
        if self.thread:
            self.thread.join()
        sys.stdout.write("\rDone!            \n")
        sys.stdout.flush()




#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

from .set_logging import get_logger
from .parameters import get_params
from .show import show_response, show_status
from .header import get_session_headers, session_path
from .spinner import Spinner


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2022 SATURN
# AUTHORS
# Sukbong Kwon (Galois)

from functools import reduce
from typing import Text
from argparse import Namespace
from type_docopt import docopt

def args2params(args):
    repls =  {'--' : '', '<': '', '>' : '', '-': '_'}
    params = {}
    for key, val in args.items():
        params[reduce(lambda a, kv: a.replace(*kv), repls.items(), key)] = val
    return params

def arg2kwargs(args):
    return reduce(lambda a, kv: a.update(kv) or a, args2params(args).items(), {})


def get_params(
    __doc__,
)-> Namespace:
    args = docopt(__doc__)
    return Namespace(**args2params(args))


#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2022-2023 SATURN
# AUTHORS
# Sukbong Kwon (Galois)

"""Set logging configuration
"""

import logging

logging.basicConfig(
    level=logging.INFO,
    format="%(asctime)s.%(msecs)03d: %(funcName)s: %(message)s",
    # format="%(asctime)s.%(msecs)03d: %(name)-20s: %(levelname)s: %(funcName)s(): %(message)s",
    datefmt="%Y-%m-%d %p %I:%M:%S",
)

def get_logger(name):
    return logging.getLogger(name)





#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- SATURN
# AUTHORS
# Sukbong Kwon (Galois)

"""
파스칼 표기법 (PascalCase):

	- 각 단어의 첫 글자를 대문자로 쓰며, 첫 번째 단어도 대문자로 시작합니다.
	- 예: VoiceSeparation, MyVariableName, TotalCount
	- 클래스 이름이나 타입 이름에 자주 사용됩니다.

로워카멜 표기법 (lowerCamelCase):

	- 첫 단어의 첫 글자를 소문자로 시작하고, 나머지 단어의 첫 글자를 대문자로 씁니다.
	- 주로 변수명이나 함수명에 사용됩니다.
	- 예: voiceSeparation, myVariableName, calculateTotal

스네이크 표기법 (snake_case):

	- 단어를 밑줄로 구분하며, 모든 글자를 소문자로 씁니다.
	- 예: voice_separation, my_variable_name, total_count
	- 파이썬에서는 변수명이나 함수명에 자주 사용됩니다.

케밥 표기법 (kebab-case):

	- 단어를 하이픈(-)으로 구분하며, 모든 글자를 소문자로 씁니다.
	- 예: voice-separation, my-variable-name, total-count
	- URL 경로나 HTML/CSS 클래스 이름에서 자주 사용됩니다.
*/
"""

from typing import Text

# Snake -> Pascal
# service_plan -> ServicePlan
def snake_to_pascal(snake: Text) -> Text:
    return ''.join(word.capitalize() for word in snake.split('_'))

# Pascal -> Snake
# ServicePlan -> service_plan
def pascal_to_snake(pascal: Text) -> Text:
    return ''.join(['_' + c.lower() if c.isupper() else c for c in pascal]).lstrip('_')

# Snake -> Camel
# service_plan -> servicePlan
def snake_to_camel(snake: Text) -> Text:
    pascal = snake_to_pascal(snake)
    return pascal[0].lower() + pascal[1:]

# Camel -> Snake
# servicePlan -> service_plan
def camel_to_snake(camel: Text) -> Text:
    return pascal_to_snake(camel)


# Camel -> Pascal
# servicePlan -> ServicePlan
def camel_to_pascal(camel: Text) -> Text:
    return camel.capitalize()

# Pascal -> Camel
# ServicePlan -> servicePlan
def pascal_to_camel(pascal: Text) -> Text:
    return pascal[0].lower() + pascal[1:]





#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

# 환경변수를 가져옵니다. ('ENDPOINT' 라는 이름으로)
import os
ENDPOINT = os.getenv("ENDPOINT")


if ENDPOINT == "snu3":
    FRAMEWORK_ENDPOINT = "http://snu3.mago52.com:8506/v1/go"       # wawa 개발 환경
elif ENDPOINT == "m3":
    FRAMEWORK_ENDPOINT = "http://audion.mago52.com:8506/v1/go"     # Audion
elif ENDPOINT == "snu1":
    FRAMEWORK_ENDPOINT = "http://dev.mago52.com:8506/v1/go"     # Audion
else:
    FRAMEWORK_ENDPOINT = "http://localhost:8506/v1/go"

HEADERS = {
    "Accept": "application/json",
    "Authorization": "Bearer eadc5d8d-ahno-9559-yesa-8c053e0f1f69",
}



#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import json
from typing import Text, Any, Dict

def show_response(
    title: Text,
    url: Text,
    response: Any,
):
    print ("=" * 100)
    print (f"Title: {title}")
    print (f"URL: {url}")
    print (f"Status Code: {response.status_code}")
    print ("Response:")
    # Show the content in the response
    # print(response.__dict__)

    try:
        print (json.dumps(response.json(), indent=4, ensure_ascii=False))
    except:
        print ("\t", response.text)
        # content = response.__dict__.get('_content')
        # if type(content) == bytes:
        #     print (content.decode('utf-8'))
        # else:
        #     json_data = json.loads(response.__dict__.get('_content').decode('utf-8'))
        #     print (json.dumps(json_data), indent=4, ensure_ascii=False)

    print ("=" * 100)


def show_status(
    title: Text,
    response,
)-> None:
    if response:
        # Check the status code
        if response.status_code == 200:
            print (f"[{title}] Success")
        else:
            print (f"[{title}] {response.json()}")
    else:
        print (f"[{title}] {response.json()}")






#!/usr/bin/env python
# encoding: utf-8
# Copyright (c) 2024- MAGO
# AUTHORS:
# Sukbong Kwon (Galois)

import json
from typing import Text, Dict
from pathlib import Path
from ..config import HEADERS

# Set the session path under the user's home directory
session_path = f"{Path.home()}/.mirinae/session.json"

def get_session_headers(
    session_path: Text,
)-> Dict:
    """세션 데이터 헤더 가져오기

    Parameters
    ----------
    session_path: Text
        세션 데이터 파일 경로

    Returns
    -------
    Dict
        세션 데이터 헤더
    """
    if not Path(session_path).exists():
        raise ValueError('Session data is required')

    with open(session_path, 'r') as f:
        sess_data = json.load(f)

    headers = {
        'Cookie': '; '.join([f'{key}={value}' for key, value in sess_data.items()])
    }
    headers.update(HEADERS)

    return headers
